Closed Bug 1940754 Opened 1 year ago Closed 1 year ago

Update to ruff 0.9.0

Categories

(Developer Infrastructure :: Lint and Formatting, task)

task

Tracking

(firefox136 fixed)

RESOLVED FIXED
136 Branch
Tracking Status
firefox136 --- fixed

People

(Reporter: Sylvestre, Assigned: Sylvestre)

References

(Blocks 1 open bug)

Details

Attachments

(1 external file)

Assignee: nobody → sledru
Status: NEW → ASSIGNED

Would be interesting to see the time save from each ruff upgrade we have done - after all speed is one of the USPs of ruff :)
(and then perhaps mentioning it to the ruff devs)

time save ? where ?

improvement in the time taken by the linting jobs.
As an example, an older version of Ruff (maybe V4?) was supposed to be 20%-50% faster than the previous versions because they rewrote the parser.

oh yes :)
for sure

Pushed by sledru@mozilla.com: https://hg.mozilla.org/integration/autoland/rev/557d142a222f Update to ruff 0.9.0 r=linter-reviewers,ahal DONTBUILD
Status: ASSIGNED → RESOLVED
Closed: 1 year ago
Resolution: --- → FIXED
Target Milestone: --- → 136 Branch
No longer blocks: 1936388
Depends on: 1936388
Blocks: 1965564
No longer blocks: 1965564
Blocks: ruff
You need to log in before you can comment on or make changes to this bug.

Attachment

General

Created:
Updated:
Size: